# astrocalc

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/astrocalc)](https://pypi.org/project/astrocalc/)  
[![](https://img.shields.io/pypi/v/astrocalc)](https://pypi.org/project/astrocalc/)  
[![](https://img.shields.io/github/license/thespacedoctor/astrocalc)](https://github.com/thespacedoctor/astrocalc)  
[![](https://img.shields.io/pypi/dm/astrocalc)](https://pypi.org/project/astrocalc/)  

<!-- STATUS BADGES -->  

[![](http://167.99.90.204:8080/buildStatus/icon?job=astrocalc%2Fmaster&subject=build%20master)](http://167.99.90.204:8080/blue/organizations/jenkins/astrocalc/activity?branch=master)  
[![](http://167.99.90.204:8080/buildStatus/icon?job=astrocalc%2Fdevelop&subject=build%20dev)](http://167.99.90.204:8080/blue/organizations/jenkins/astrocalc/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/astrocalc@master/coverage.svg)](https://raw.githack.com/thespacedoctor/astrocalc/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/astrocalc/badge/)](http://astrocalc.readthedocs.io/en/latest/?badge)  
[![](https://img.shields.io/github/issues/thespacedoctor/astrocalc/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/astrocalc/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*perform common astronomy-related calculations, conversions and measurements within python scripts or from the command-line*.

Documentation for astrocalc is hosted by [Read the Docs](http://astrocalc.readthedocs.org/en/stable/) (last
[stable version](http://astrocalc.readthedocs.org/en/stable/) and [latest version](http://astrocalc.readthedocs.org/en/latest/)). The code lives on [github](https://github.com/thespacedoctor/astrocalc). Please report any issues you find [here](https://github.com/thespacedoctor/astrocalc/issues).

## Features

* 



